@@ -3,13 +3,13 @@ import logging
 import signal
 from argparse import RawDescriptionHelpFormatter
 
-from seleniumwire.proxy import backend, utils
+from seleniumwire import backend, utils
 
 logging.basicConfig(level=logging.DEBUG, format='%(message)s')
 
 
-def standalone_proxy(port=0):
-    b = backend.create(port=int(port), options={
+def standalone_proxy(port=0, addr='127.0.0.1'):
+    b = backend.create(port=int(port), addr=addr, options={
         'standalone': True,
         'verify_ssl': False,
     })
