@@ -1,13 +1,18 @@
+from selenium.webdriver import ActionChains  # noqa
 from selenium.webdriver import Chrome as _Chrome
 from selenium.webdriver import ChromeOptions
+from selenium.webdriver import DesiredCapabilities
 from selenium.webdriver import Edge as _Edge
 from selenium.webdriver import Firefox as _Firefox
+from selenium.webdriver import FirefoxOptions  # noqa
+from selenium.webdriver import FirefoxProfile  # noqa
 from selenium.webdriver import Remote as _Remote
 from selenium.webdriver import Safari as _Safari
-from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
+from selenium.webdriver import Proxy  # noqa
+from selenium.webdriver import TouchActions  # noqa
 
-from . import backend
-from .inspect import InspectRequestsMixin
+from seleniumwire import backend
+from seleniumwire.inspect import InspectRequestsMixin
 
 
 class DriverCommonMixin:
