@@ -1,5 +1,6 @@
+from collections.abc import Iterator
 from unittest import TestCase
-from unittest.mock import Mock
+from unittest.mock import Mock, patch
 
 from seleniumwire.inspect import InspectRequestsMixin, TimeoutException
 
@@ -32,6 +33,11 @@ class InspectRequestsMixinTest(TestCase):
 
         self.mock_proxy.storage.clear_requests.assert_called_once_with()
 
+    def test_iter_requests(self):
+        self.mock_proxy.storage.iter_requests.return_value = iter([Mock()])
+
+        self.assertIsInstance(self.driver.iter_requests(), Iterator)
+
     def test_last_request(self):
         self.mock_proxy.storage.load_last_request.return_value = Mock()
 
@@ -65,6 +71,23 @@ class InspectRequestsMixinTest(TestCase):
         self.assertTrue(self.mock_proxy.storage.find.call_count > 0)
         self.assertTrue(self.mock_proxy.storage.find.call_count <= 5)
 
+    @patch('seleniumwire.inspect.har')
+    def test_har(self, mock_har):
+        self.mock_proxy.storage.load_har_entries.return_value = [
+            'test_entry1',
+            'test_entry2',
+        ]
+        mock_har.generate_har.return_value = 'test_har'
+
+        har = self.driver.har
+
+        self.assertEqual('test_har', har)
+        self.mock_proxy.storage.load_har_entries.assert_called_once_with()
+        mock_har.generate_har.assert_called_once_with([
+            'test_entry1',
+            'test_entry2',
+        ])
+
     def test_set_header_overrides(self):
         header_overrides = {
             'User-Agent': 'Test_User_Agent_String',
